Async RPC client for Ethereum
-----------------------------

[![pypi package][pypi-image]][pypi-link] ![License][pypi-license-image] [![Docs][rtd-image]][rtd-link] [![Coverage][cov-image]][cov-link] [![Code style: black][black-image]][black-link]

An experimental client for those who think that [`web3`](https://github.com/ethereum/web3.py) grew too unwieldy, and also wants [`trio`](https://github.com/python-trio/trio) support.

For more information see [the documentation](https://pons.readthedocs.io/en/latest/).


[pypi-image]: https://img.shields.io/pypi/v/pons
[pypi-link]: https://pypi.org/project/pons/
[pypi-license-image]: https://img.shields.io/pypi/l/pons
[rtd-image]: https://readthedocs.org/projects/pons/badge/?version=latest
[rtd-link]: https://pons.readthedocs.io/en/latest/
[cov-image]: https://codecov.io/gh/fjarri-eth/pons/branch/master/graph/badge.svg?token=RZP1LK1HB2
[cov-link]: https://codecov.io/gh/fjarri-eth/pons
[black-image]: https://img.shields.io/badge/code%20style-black-000000.svg
[black-link]: https://github.com/psf/black
